@@ -61,7 +61,8 @@ od_get_server_list (const gchar **required_ids)
                         ODServerInfo *info;
 
                         info = od_server_info_new (goad_list->list [i].server_id,
-						   goad_list->list [i].description);
+						   goad_list->list [i].description,
+						   NULL);
                         retval = g_list_prepend (retval, info);
 		}
 
@@ -137,7 +138,13 @@ od_assert_using_goad (void)
 void
 od_assert_using_oaf  (void)
 {
-        g_warning("Your Bonobo library is compiled to use GOAD (from gnome-libs 1.0)\n"
-                  "This program requires a Bonobo compiled to use OAF instead.");
+        g_warning("Your Bonobo library is compiled to use GOAD (from gnome-libs 1.0).");
+	g_error("This program requires a Bonobo compiled to use OAF instead.");
         exit(1);
 }
+
+CORBA_Object
+od_name_service_get (CORBA_Environment *ev)
+{
+	return gnome_name_service_get ();
+}
