@@ -198,8 +198,8 @@ GtkAccelGroup		*bonobo_ui_handler_get_accelgroup		(BonoboUIHandler *uih);
  * This path-building routine will be used for both toolbar and menu
  * item paths.
  */
-char			*bonobo_ui_handler_build_path			(char *comp1, ...);
-char			*bonobo_ui_handler_build_path_v			(va_list path_components);
+char			*bonobo_ui_handler_build_path			(const char *base, ...);
+char			*bonobo_ui_handler_build_path_v			(const char *base, va_list path_components);
 
 /*
  * Menus.
