@@ -116,7 +116,7 @@ typedef struct _MenuItemInternal {
 
 	/*
 	 * If this item is a radio group, then this list points to the
-	 * MenuItemInternal structures for the members of the group.
+	 * GtkRadioMenuItem widgets for the members of the group.
 	 */
 	GSList *radio_items;
 
@@ -177,12 +177,6 @@ struct _ToolbarItemInternal {
 	 */
 	Bonobo_UIHandler uih_corba;
 
-	/*
-	 * If this item is a radio group, then this list points to the
-	 * ToolbarItemInternal structures for the members of the group.
-	 */
-	GSList *radio_items;
-
 	/*
 	 * In the world of toolbars, only radio groups can have
 	 * children.
