@@ -7,7 +7,13 @@
  */
 #include <config.h>
 #include <gnome.h>
+
+#if USING_OAF
+#include <liboaf/liboaf.h>
+#else
 #include <libgnorba/gnorba.h>
+#endif
+
 #include <bonobo.h>
 
 /* XPM */
@@ -868,9 +874,15 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 static void
 init_bonobo_text_plain_factory (void)
 {
+#if USING_OAF
+	factory = bonobo_embeddable_factory_new (
+                "OAFIID:bonobo_text-plain_factory:ac6af073-f87c-4f69-b6a2-2ae4aea0bb85",
+		embeddable_factory, NULL);
+#else
 	factory = bonobo_embeddable_factory_new (
 		"embeddable-factory:text-plain",
 		embeddable_factory, NULL);
+#endif
 } /* init_bonobo_text_plain_factory */
 
 static void
@@ -881,11 +893,19 @@ init_server_factory (int argc, char **argv)
 
 	CORBA_exception_init (&ev);
 	
+#if USING_OAF
+        gnome_init_with_popt_table("bonobo-text-plain", VERSION,
+				   argc, argv,
+				   oaf_popt_options, 0, NULL); 
+	orb = oaf_init (argc, argv);
+#else
 	gnome_CORBA_init_with_popt_table (
 		"bonobo-text-plain", VERSION,
 		&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
+	orb = gnome_CORBA_ORB ();
+#endif
 
-	if (bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL) == FALSE)
+	if (bonobo_init (orb, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL) == FALSE)
 		g_error (_("I could not initialize Bonobo"));
 
 	CORBA_exception_free (&ev);
