@@ -8,9 +8,11 @@
  * Copyright 1999 Maurer IT Systemlsungen (http://www.maurer-it.com)
  */
 
+#include <config.h>
 #include "gshell.h"
 #include "inout.h"
 #include "menu.h"
+#include "properties.h"
 #include <libgnorba/gnorba.h>
 
 Application app;
@@ -53,7 +55,11 @@ help_menu_about_cb (BonoboUIHandler *uih, void *data, char *path)
 void 
 edit_menu_preferences_cb (BonoboUIHandler *uih, void *data, char *path)
 {
-	g_warning ("edit_menu_properties_cb not implemented");
+	Frame *frame;
+
+	if (!(frame = get_active_frame (GTK_WIDGET (bonobo_ui_handler_get_app (uih))))) return;
+
+	show_property_dialog (BONOBO_CONTROL_FRAME (frame->active_view_frame));
 }
 
 /*
@@ -550,7 +556,7 @@ main (int argc, char **argv)
 	orb = gnome_CORBA_ORB ();
 
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
-		g_error (_("Could not initialize Bonobo!\n"));
+		g_error (_("Could not initialize Bonobo!"));
 
 	app.container = bonobo_container_new ();
 	gtk_signal_connect (GTK_OBJECT (app.container), "system_exception",
